# CHANGELOG

## v1.1.0 (2024-08-27)

### Feature

* feat: Update agent.py ([`10b2fe3`](https://github.com/mindfiredigital/neo-pusher/commit/10b2fe357306d9057f5962171737819096f9c1b1))

* feat: added necessary print statement ([`21836cd`](https://github.com/mindfiredigital/neo-pusher/commit/21836cd57aa0571588cbc37ddf4db38dec3f7936))

### Fix

* fix: Update workflow.yml ([`fa24152`](https://github.com/mindfiredigital/neo-pusher/commit/fa2415205f1c6a02a6607718dd2c246b0b60963d))

* fix: Update setup.cfg ([`aa46577`](https://github.com/mindfiredigital/neo-pusher/commit/aa46577d84d5a0e750aae1a2f93d996f34afe646))

* fix: Update workflow.yml ([`9f54707`](https://github.com/mindfiredigital/neo-pusher/commit/9f547074c75b17338bd82da55c8837b0a1065d8c))

* fix: Update workflow.yml ([`a33f231`](https://github.com/mindfiredigital/neo-pusher/commit/a33f2315f20d5c1543fdadd06e1717fe7bcdd8cd))

* fix: Update workflow.yml ([`3d8daea`](https://github.com/mindfiredigital/neo-pusher/commit/3d8daea8620155b573be89a3ba834febd543018c))

* fix: Update workflow.yml ([`3192eb7`](https://github.com/mindfiredigital/neo-pusher/commit/3192eb7d187234a674fb0ea9967e79014cff559b))

* fix: Update workflow.yml ([`403e22c`](https://github.com/mindfiredigital/neo-pusher/commit/403e22c68a96e19f3eceaa2e4e63e8945423cc6c))

* fix: Update workflow.yml ([`5073bc9`](https://github.com/mindfiredigital/neo-pusher/commit/5073bc9aeb74f84095d7615a46e7e0c9dc1cc8f6))

* fix: Update workflow.yml ([`593bf08`](https://github.com/mindfiredigital/neo-pusher/commit/593bf0884a9054308eac8aa8c9715b98e1d3ad61))

* fix: Update workflow.yml ([`54b2599`](https://github.com/mindfiredigital/neo-pusher/commit/54b25993dfe1a8db93b7a4d691beaf64c306dd5a))

* fix: Update setup.cfg ([`df33afb`](https://github.com/mindfiredigital/neo-pusher/commit/df33afb1f1672a1d7ccfbe7b18212af0754d648f))

* fix: Update workflow.yml ([`2694fb7`](https://github.com/mindfiredigital/neo-pusher/commit/2694fb711e242ccf98ed09e277e3a82a994bc9ac))

* fix: Update workflow.yml ([`433d90c`](https://github.com/mindfiredigital/neo-pusher/commit/433d90c0b18d7d0fda772e81a657f98a67515e03))

* fix: Update setup.py ([`c28fe19`](https://github.com/mindfiredigital/neo-pusher/commit/c28fe1936fe5ca363c5a916c05eaa3e1c8456e85))

* fix: Update workflow.yml ([`f722024`](https://github.com/mindfiredigital/neo-pusher/commit/f72202488f3655e27bcfa25afa7d6f17fc6623df))

* fix: Update workflow.yml ([`6c108b7`](https://github.com/mindfiredigital/neo-pusher/commit/6c108b706f63510a9c8d2ee7568f34ee9ac83f14))

* fix: Update setup.cfg ([`e225cd6`](https://github.com/mindfiredigital/neo-pusher/commit/e225cd6d0236f3deb821ae8ab93a9fa2b209aebf))

* fix: Update setup.cfg ([`7abc2d1`](https://github.com/mindfiredigital/neo-pusher/commit/7abc2d1bd8dfa76489bfc393c0a6ff894f351964))

* fix: Update setup.cfg ([`0ad7a40`](https://github.com/mindfiredigital/neo-pusher/commit/0ad7a406315d06bb4297e3a01842e131cc70d108))

* fix: Update workflow.yml ([`bb8bd19`](https://github.com/mindfiredigital/neo-pusher/commit/bb8bd1909c9a4928acdd6d53547e92a7f2893b3d))

* fix: Update setup.cfg ([`4652674`](https://github.com/mindfiredigital/neo-pusher/commit/465267447f7b2ee61bd13a9de84b785cdbeaf98d))

* fix: Update setup.cfg ([`5e95e31`](https://github.com/mindfiredigital/neo-pusher/commit/5e95e316ab9a7f000d03594353fea65ef0049bc2))

* fix: Update setup.py ([`7d231c2`](https://github.com/mindfiredigital/neo-pusher/commit/7d231c2433a2c8056c0515c3d15bacd2ca3af4f9))

* fix: Update setup.cfg ([`b3b1d27`](https://github.com/mindfiredigital/neo-pusher/commit/b3b1d27f75aa36c8d030ef15f5ec9705c3f48ea6))

* fix: Update workflow.yml ([`47c7137`](https://github.com/mindfiredigital/neo-pusher/commit/47c7137c76ef8d7c587ee23c10f95c18dca9d18c))

* fix: Update workflow.yml ([`6ef557b`](https://github.com/mindfiredigital/neo-pusher/commit/6ef557b14cf846b09c163bbca75839d0cba0facb))

* fix: Update workflow.yml ([`4c38367`](https://github.com/mindfiredigital/neo-pusher/commit/4c38367ca279bec8f7324571a5738cad4c56d116))

* fix: Update setup.py ([`49125d0`](https://github.com/mindfiredigital/neo-pusher/commit/49125d0607f06555a901a56190ce132420585ed5))

* fix: Update workflow.yml ([`fad38cd`](https://github.com/mindfiredigital/neo-pusher/commit/fad38cd498dc08ce729def266adeae15113adb80))

* fix: Update workflow.yml ([`6d9e98e`](https://github.com/mindfiredigital/neo-pusher/commit/6d9e98eb3997485c7fcc4cd04794f56bb4c84a2f))

* fix: Update workflow.yml ([`1acb592`](https://github.com/mindfiredigital/neo-pusher/commit/1acb592bf9ebe0cffbb1ec17818e2377ded95dea))

* fix: Update workflow.yml ([`12f3c03`](https://github.com/mindfiredigital/neo-pusher/commit/12f3c037492a1b78e7dc6e024434689f80a588c8))

* fix: Update workflow.yml ([`bd44800`](https://github.com/mindfiredigital/neo-pusher/commit/bd4480004532d1c23020323f69877ec1f7c281b9))

* fix: Update workflow.yml ([`b2470bf`](https://github.com/mindfiredigital/neo-pusher/commit/b2470bf02fe0277a0a4c2bd5e4967d0848ce2530))

* fix: Update setup.py ([`374f3a4`](https://github.com/mindfiredigital/neo-pusher/commit/374f3a405fcfe6ccf0715e015af4ff56e179c003))

* fix: Update setup.py ([`15f8051`](https://github.com/mindfiredigital/neo-pusher/commit/15f8051e725e369506a6857b4cb8a081d4151cce))

* fix: Update setup.py ([`3912670`](https://github.com/mindfiredigital/neo-pusher/commit/3912670a7c18a12942506c959641657a7b271bc1))

* fix: Update setup.py ([`6139c8b`](https://github.com/mindfiredigital/neo-pusher/commit/6139c8bd85c3a96bb0fbe63b7db3d5883206a9b4))

* fix: Update setup.py ([`6e82052`](https://github.com/mindfiredigital/neo-pusher/commit/6e820522d3d9a8f3f760d9a154fbae47ae2fb5df))

* fix: Update workflow.yml ([`e2cc55f`](https://github.com/mindfiredigital/neo-pusher/commit/e2cc55f2c9a0e74a716d18871f6dd04baf660954))

* fix: Update workflow.yml ([`5b72832`](https://github.com/mindfiredigital/neo-pusher/commit/5b72832d2b060a94ef63ec89b0744daf7635d383))

* fix: Update setup.py ([`6ba2ea1`](https://github.com/mindfiredigital/neo-pusher/commit/6ba2ea172e36cd992d5ea8e42f197a127f95dcfa))

* fix: Update setup.py ([`c5a2e40`](https://github.com/mindfiredigital/neo-pusher/commit/c5a2e40299e6deabb5cf2a5225290e2eaad48252))

* fix: Update setup.py ([`2900300`](https://github.com/mindfiredigital/neo-pusher/commit/2900300b78b23c45d7b1167dc20da613067aa09e))

* fix: Update workflow.yml ([`d587890`](https://github.com/mindfiredigital/neo-pusher/commit/d587890126f5867d4d57d318e43ac6bd3d144fe2))

* fix: conslict resolve ([`a0b7461`](https://github.com/mindfiredigital/neo-pusher/commit/a0b746165d371cdbe87a007da4deb411fb110157))

* fix: add release info in workflow ([`b1176fb`](https://github.com/mindfiredigital/neo-pusher/commit/b1176fb3b5da3db7f8957cf58a7a203fb4a2271c))

* fix: add release info in workflow ([`2bcd7d4`](https://github.com/mindfiredigital/neo-pusher/commit/2bcd7d4dd92bc9f460259d3b865f61a531f0d31d))

* fix: add release info in workflow ([`91227bc`](https://github.com/mindfiredigital/neo-pusher/commit/91227bc852e56e8e8b1215087f6b5e341832b2a0))

* fix: add release info in workflow ([`b8a22b9`](https://github.com/mindfiredigital/neo-pusher/commit/b8a22b9fdc0f12939481c65b1efcac288cfca3f7))

* fix: add release info in workflow ([`33a7f4d`](https://github.com/mindfiredigital/neo-pusher/commit/33a7f4dc47a37c28f117f1b84396cdf91f61ecb1))

* fix: resolve merge conflict in workflow ([`0d1af06`](https://github.com/mindfiredigital/neo-pusher/commit/0d1af0679c666a4e6377829fd8d5609d100c2496))

* fix: update permission in workflow ([`29bab7b`](https://github.com/mindfiredigital/neo-pusher/commit/29bab7bdde0c864cb28ba1399442876bf19dffb6))

### Unknown

* fit: Update workflow.yml ([`4a7b0d8`](https://github.com/mindfiredigital/neo-pusher/commit/4a7b0d8b22812a96d0ef4c7c6c88669bc014d2f4))

* fitx: Update workflow.yml ([`199f150`](https://github.com/mindfiredigital/neo-pusher/commit/199f150071854aea12266d2202c726ea803d0ffb))

* fox: Update setup.cfg ([`8a8221c`](https://github.com/mindfiredigital/neo-pusher/commit/8a8221c5335655a2ebba65fbd2b1847b1cc31973))

* fit : Update setup.cfg ([`aff67df`](https://github.com/mindfiredigital/neo-pusher/commit/aff67df557e9ab5db87a4ccf412a8f688466ed4f))

* fit: Update workflow.yml ([`bf1ded9`](https://github.com/mindfiredigital/neo-pusher/commit/bf1ded934e4d12f3d246a1f2da061e64c079d1db))

* fit: Update workflow.yml ([`0d05f60`](https://github.com/mindfiredigital/neo-pusher/commit/0d05f60e05e8c3adc86cfc640b5b01ba07eede78))

* fit: Update workflow.yml ([`648cf87`](https://github.com/mindfiredigital/neo-pusher/commit/648cf87c363f6e0ae388f4443d9341b47ad6ef82))

* fit: Update workflow.yml ([`c233a4c`](https://github.com/mindfiredigital/neo-pusher/commit/c233a4ce4d472a753faedca03f6aa916a952bc0b))

* fit: Update workflow.yml ([`0a61b8c`](https://github.com/mindfiredigital/neo-pusher/commit/0a61b8c38f7472f967b4f6ab6b405dcc31527fd7))

* fix:Update setup.cfg ([`6e5c033`](https://github.com/mindfiredigital/neo-pusher/commit/6e5c033df2d883733df299201b6a97af308a964d))

* Update workflow.yml ([`8f3669a`](https://github.com/mindfiredigital/neo-pusher/commit/8f3669a4a9afd34587a6ae037378ccceae81abfb))

* Update workflow.yml ([`857a34d`](https://github.com/mindfiredigital/neo-pusher/commit/857a34d24f27d1ad6ef5ec82edbb52e4f23cb0a2))

* Update setup.cfg ([`e6e1df6`](https://github.com/mindfiredigital/neo-pusher/commit/e6e1df62ca73583c861c693e459b1a31049f556f))

* Update workflow.yml ([`08329dd`](https://github.com/mindfiredigital/neo-pusher/commit/08329ddb8d864e920e6af784fc469c6054d9dbc2))

* Update workflow.yml ([`b924454`](https://github.com/mindfiredigital/neo-pusher/commit/b92445430ecd77c18c8157148025069dd906505c))

* Update workflow.yml ([`c12b4fa`](https://github.com/mindfiredigital/neo-pusher/commit/c12b4fa72fe00442cdfb5af1c8147e0a56e05c84))

* Update workflow.yml ([`f5d8adb`](https://github.com/mindfiredigital/neo-pusher/commit/f5d8adbabf9e0e65723edbf3b229a091ff1ded79))

* Update workflow.yml ([`d49a112`](https://github.com/mindfiredigital/neo-pusher/commit/d49a11281e68b9840a786ebefa84f7bf4a69a6f5))

* Update workflow.yml ([`d9a8302`](https://github.com/mindfiredigital/neo-pusher/commit/d9a83025358e39689b41bebc2a31dfb8cfd2a612))

* Update workflow.yml ([`62273b2`](https://github.com/mindfiredigital/neo-pusher/commit/62273b28641ba47584df6fb34a00f785d9bd9805))

* Update workflow.yml ([`c269428`](https://github.com/mindfiredigital/neo-pusher/commit/c269428f151f9ddb7d122e5d5db4d9e030da11ee))

* Update workflow.yml ([`3611f32`](https://github.com/mindfiredigital/neo-pusher/commit/3611f329f4680cc7e869b68eeac96b391ab08cac))

* Update setup.cfg ([`d098a94`](https://github.com/mindfiredigital/neo-pusher/commit/d098a9453e120c810feafb8d16dccb3ef1a1ee56))

* Update workflow.yml ([`1d5a79e`](https://github.com/mindfiredigital/neo-pusher/commit/1d5a79e9979268e92bb36c71b9a27e081703d2a4))

* Update workflow.yml ([`12515dd`](https://github.com/mindfiredigital/neo-pusher/commit/12515ddbabe0c6ca52418c7a740f4445db09c1aa))

* Update workflow.yml ([`bd8727d`](https://github.com/mindfiredigital/neo-pusher/commit/bd8727d34ffcbad86448b988c0c39996eae5d662))

* Update workflow.yml ([`0917596`](https://github.com/mindfiredigital/neo-pusher/commit/09175964cf6618f6ddfb18c3c75991cb7452f24d))

* Update workflow.yml ([`a6765a5`](https://github.com/mindfiredigital/neo-pusher/commit/a6765a55dc161ac01f2364cfcaaed31099c338ae))

* Update workflow.yml ([`3f87532`](https://github.com/mindfiredigital/neo-pusher/commit/3f8753269bcaea8afa461fc9b31b6b4790fe397e))

* Merge pull request #25 from mindfiredigital/Siddharth-1698-patch-1

Update workflow.yml ([`0890ef8`](https://github.com/mindfiredigital/neo-pusher/commit/0890ef82d6c61b189c4d6aecffc689848e060054))

* Update workflow.yml ([`20021ae`](https://github.com/mindfiredigital/neo-pusher/commit/20021aeafa6fa4f1a927682f4778cbc259eea320))

* Update workflow.yml ([`c27fc89`](https://github.com/mindfiredigital/neo-pusher/commit/c27fc89eee3e39d8ae13950b5f5ff359dd7a8eb7))

* Update workflow.yml ([`909b988`](https://github.com/mindfiredigital/neo-pusher/commit/909b988008bf02dc0dbe01324a988e05a0fac908))

* Update workflow.yml ([`5a9c554`](https://github.com/mindfiredigital/neo-pusher/commit/5a9c554e01f3d3d3db5be15b7638a19304384e55))

* Update workflow.yml ([`f8b280f`](https://github.com/mindfiredigital/neo-pusher/commit/f8b280fe1b236399c6608b4cc4a6c197f0efb3fd))

* Update workflow.yml ([`978cc6a`](https://github.com/mindfiredigital/neo-pusher/commit/978cc6a10f2404e5c6cab80dec61f0ed24dc72ad))

* Merge pull request #24 from mindfiredigital/Siddharth-1698-patch-1

Update workflow.yml ([`f041d11`](https://github.com/mindfiredigital/neo-pusher/commit/f041d11e28d85c07bd743b7e137c53397de14821))

* Update workflow.yml ([`ca124c7`](https://github.com/mindfiredigital/neo-pusher/commit/ca124c7f394201ee340bad5aa5ef91b450f0871e))

* Update workflow.yml ([`3a9b0f5`](https://github.com/mindfiredigital/neo-pusher/commit/3a9b0f5104ec114f9e4311fe8efa3f2d96eb97d1))

* Update workflow.yml ([`15d2223`](https://github.com/mindfiredigital/neo-pusher/commit/15d22232277d01487dcba27cfadc2a72a3a4740d))

* Update workflow.yml ([`76b7ec6`](https://github.com/mindfiredigital/neo-pusher/commit/76b7ec6e7b38296752e5350fdd88348b6283b1c9))

* Merge pull request #23 from mindfiredigital/dev

fix: add release info in workflow ([`4552bbb`](https://github.com/mindfiredigital/neo-pusher/commit/4552bbb42ffc5bf4d1511991d55018a57b33bed4))

* Update workflow.yml ([`9ac5581`](https://github.com/mindfiredigital/neo-pusher/commit/9ac5581310c0e50491b5152c8ecfa9b792f8d7c6))

* Merge pull request #22 from mindfiredigital/dev

feat: added necessary print statement ([`cc1d1f2`](https://github.com/mindfiredigital/neo-pusher/commit/cc1d1f2fdd9e7625d7e88d32b2b4909558069811))

* Merge pull request #21 from mindfiredigital/dev

fix: add release info in workflow ([`242b4c1`](https://github.com/mindfiredigital/neo-pusher/commit/242b4c1d65cb76546be329125181bd5aa3cc87e6))

* Merge pull request #20 from mindfiredigital/dev

fix: add release info in workflow ([`c53ec1e`](https://github.com/mindfiredigital/neo-pusher/commit/c53ec1e7bf037520def508e225aec0c43a29f524))

* Merge pull request #19 from mindfiredigital/dev

fix: add release info in workflow ([`71ab29c`](https://github.com/mindfiredigital/neo-pusher/commit/71ab29cbc16305db883181b2e44f4ea7a62c0300))

* Merge pull request #18 from mindfiredigital/dev

fix: add release info in workflow ([`69d7f0a`](https://github.com/mindfiredigital/neo-pusher/commit/69d7f0abca1c37385193533fb1397bbb0e15c6cc))

* Merge pull request #17 from mindfiredigital/dev

fix: update permission in workflow ([`7320117`](https://github.com/mindfiredigital/neo-pusher/commit/7320117759956cce100d7c32690762228dc064ec))

* Merge pull request #16 from mindfiredigital/dev

fix: update permission in workflow ([`350e9f9`](https://github.com/mindfiredigital/neo-pusher/commit/350e9f9e62cec85bb6da96024266d62893e7b5e1))

* Merge pull request #15 from mindfiredigital/dev

chore: update git ignore ([`e8074e6`](https://github.com/mindfiredigital/neo-pusher/commit/e8074e6c73679ad076bc3e15d77bde151c630e29))

* Merge pull request #14 from mindfiredigital/dev

fix: update readme, setup.cfg , and correct folder name ([`ba0011d`](https://github.com/mindfiredigital/neo-pusher/commit/ba0011db1f8b1f18ee8a8e7e3296a0ebeecb2152))

* Merge pull request #13 from mindfiredigital/dev

feat: add version in init ([`302165f`](https://github.com/mindfiredigital/neo-pusher/commit/302165fd90050c115c268e2c03bf61f6adb7e405))

* Merge pull request #12 from mindfiredigital/dev

chore: removed github token from workflow ([`dbb909d`](https://github.com/mindfiredigital/neo-pusher/commit/dbb909dfdadd63903a7c5b866f92afb587df25aa))

* Merge pull request #11 from mindfiredigital/dev

chore: add version source in setup ([`77a2ede`](https://github.com/mindfiredigital/neo-pusher/commit/77a2ede42f4c537059a8756af6d8aed6dceff376))

* Merge pull request #10 from mindfiredigital/dev

chore: add workflow dispatch for mannual trigger ([`3c7ad2c`](https://github.com/mindfiredigital/neo-pusher/commit/3c7ad2cb15e971b8aa81ec26f84206da8d3ec6b6))

* Merge pull request #9 from mindfiredigital/dev

chore: Change setup.cfg for versions ([`fd3941f`](https://github.com/mindfiredigital/neo-pusher/commit/fd3941f5195ec45c2c422929d435b691e8f9c0c5))

* Merge pull request #8 from mindfiredigital/dev

chore: add package name in setup.cfg ([`0f63ee7`](https://github.com/mindfiredigital/neo-pusher/commit/0f63ee7c1333097d3dd1e9db998f540f035591df))

* Merge pull request #7 from mindfiredigital/dev

fix: semantic release issue ([`7b75d48`](https://github.com/mindfiredigital/neo-pusher/commit/7b75d48019a4709c3db5cebd32b0890b0590e600))

* Merge pull request #6 from mindfiredigital/dev

fix: semantic release issue ([`b0e6f89`](https://github.com/mindfiredigital/neo-pusher/commit/b0e6f89002d85d59a3dd67b1d4b5700508742872))

* Merge pull request #5 from mindfiredigital/dev

feat: implement python semantic release ([`17688af`](https://github.com/mindfiredigital/neo-pusher/commit/17688af87cd44611b6bc86cad6e1e9c861382877))

## v1.0.0 (2024-08-22)

### Chore

* chore: update git ignore ([`ff91859`](https://github.com/mindfiredigital/neo-pusher/commit/ff918594a535e926244dcc8309498da153f0ddb1))

* chore: removed github token from workflow ([`e86f6dc`](https://github.com/mindfiredigital/neo-pusher/commit/e86f6dcc44c081e15256d4b5b85563a4f83e5f52))

* chore: add version source in setup ([`0110601`](https://github.com/mindfiredigital/neo-pusher/commit/0110601e73bcae84b34005523f9573fd6f69e6a6))

* chore: add workflow dispatch for mannual trigger ([`2e0ed18`](https://github.com/mindfiredigital/neo-pusher/commit/2e0ed18c132291a65f602937718c6f2dc680391d))

* chore: Change setup.cfg for versions ([`08fa9aa`](https://github.com/mindfiredigital/neo-pusher/commit/08fa9aa07cbaa8dcdc4ff0d4920fc37f01bd8646))

* chore: add package name in setup.cfg ([`f1f9b0a`](https://github.com/mindfiredigital/neo-pusher/commit/f1f9b0ac44df638380606c4408cbd191c83208de))

* chore: Change README file name ([`21d5538`](https://github.com/mindfiredigital/neo-pusher/commit/21d55384d15abd1f30bbb6bf9f137ee14a02b9ab))

### Feature

* feat: add version in init ([`2ea34e4`](https://github.com/mindfiredigital/neo-pusher/commit/2ea34e4d454c2cee351b07c11b5baa46821e3144))

* feat: implement python semantic release ([`6728cc6`](https://github.com/mindfiredigital/neo-pusher/commit/6728cc614f7fc045347068b5f555ead7a41aa28d))

### Fix

* fix: update permission in workflow ([`794d4d5`](https://github.com/mindfiredigital/neo-pusher/commit/794d4d531fe983adff96d37eb292b5b1b9202680))

* fix: update permission in workflow ([`ceb3b39`](https://github.com/mindfiredigital/neo-pusher/commit/ceb3b39aa0b41e3a3c2fedde82270cb28da9c7b1))

* fix: update readme, setup.cfg , and correct folder name ([`5fb792d`](https://github.com/mindfiredigital/neo-pusher/commit/5fb792d313ab186f1b2a049478925b0a1113fd30))

* fix: semantic release issue ([`7caade1`](https://github.com/mindfiredigital/neo-pusher/commit/7caade11b8e8c343efba72c3951cda49d59305b5))

* fix: semantic release issue ([`2ae099e`](https://github.com/mindfiredigital/neo-pusher/commit/2ae099e5fb31367f8df774b9b8074caf38127944))

### Unknown

* Merge pull request #4 from mindfiredigital/dev

chore: Change README file name ([`89e9827`](https://github.com/mindfiredigital/neo-pusher/commit/89e9827e0215957eadaff7f937ab6da6f02302e7))

* Merge pull request #3 from mindfiredigital/dev

Update setup ([`4b12c08`](https://github.com/mindfiredigital/neo-pusher/commit/4b12c08e87bcbb8b9c10f4ab0c39906595828921))

* Merge pull request #2 from mindfiredigital/dev

Update license, code of conduct and change log ([`390effa`](https://github.com/mindfiredigital/neo-pusher/commit/390effab7ab6fe52d25ffed94e479ffb056c463d))

* Merge pull request #1 from mindfiredigital/dev

Update setup file and work flow ([`80c15c7`](https://github.com/mindfiredigital/neo-pusher/commit/80c15c787a8fbc65809946cc10866d782393ddef))

* Update setup ([`895ba5c`](https://github.com/mindfiredigital/neo-pusher/commit/895ba5c86852e9d67c9da553745c4d1b8205226e))

* Update license, code of conduct and change log ([`a234739`](https://github.com/mindfiredigital/neo-pusher/commit/a234739d932f684c23e5cb12ddf5078897968357))

* updated setup ([`4a16183`](https://github.com/mindfiredigital/neo-pusher/commit/4a1618325d5c06ac54493e8fb92a794a0cd38308))

* updated workflow ([`fd2d4ca`](https://github.com/mindfiredigital/neo-pusher/commit/fd2d4cafcc2a79567ccb6f441deaabe8e82d32c4))

* updated workflow ([`71e9cd3`](https://github.com/mindfiredigital/neo-pusher/commit/71e9cd3b10808461693d3211e3966f01fd1b97ce))

* Create python-publish.yml ([`ada714a`](https://github.com/mindfiredigital/neo-pusher/commit/ada714a1cfb43dfe6c3e7b78915a5a1c45bf09b3))

* updated workflow ([`162061a`](https://github.com/mindfiredigital/neo-pusher/commit/162061a1a989a7e6b8baa193d4562ff9c5282b96))

* updated workflow ([`6890852`](https://github.com/mindfiredigital/neo-pusher/commit/68908527db39279aadd9f79c25822b29f4893564))

* corrected folder structure and updated readme ([`ab3ad0c`](https://github.com/mindfiredigital/neo-pusher/commit/ab3ad0c4a32aab85e3cc46431cabc0b1bc06ad58))

* renamed folders correctly ([`d15071c`](https://github.com/mindfiredigital/neo-pusher/commit/d15071cfa224b4e667bf15d2c3b06089efa7754c))

* added workflows ([`b3cb3eb`](https://github.com/mindfiredigital/neo-pusher/commit/b3cb3eb466504c870e219d126d414c5927394563))

* solved bugs ([`5dc221a`](https://github.com/mindfiredigital/neo-pusher/commit/5dc221a6e04f2aee71d4c7816a5dca91cfc58ca7))

* initial commit ([`0dfbac7`](https://github.com/mindfiredigital/neo-pusher/commit/0dfbac7d1fac7a0ecbb1c5afdbb9e6c469e974a0))
